@@ -442,6 +442,35 @@ class calc_area:
             data['area_ac'] = data.geometry.area*(100000**2)/4046.86
             ohex = data[data['area_ac']>=self.delarea]
             self.geosolution = ohex
+
+class assign_uid:
+    
+    def __init__(self,
+                 df,
+                 attribute:str = None
+                 ):
         
+        self.df = df
+        self.attribute = attribute
+        
+        if isinstance(self.df, str):
+            data = gpd.read_file(self.df)
+            if data.crs == None:
+                data.crs = {'init': 'epsg:4326'}
+        elif isinstance(self.df, gpd.GeoDataFrame):
+            data = self.df
+            if data.crs == None:
+                data.crs = {'init':'epsg:4326'}
+        else:
+            raise KeyError(f"{self.df} is errorneous data location, please fix the data location problem")
+        
+        if self.attribute == None:
+            data['Soil_Sampl'] = range(0, 0+len(data))
+            self.geosolution = data
+        elif self.attribute != None:
+            data[f"{self.attribute}"] = range(0, 0+len(data))
+            self.geosolution = data
+        else:
+            print("You need to apecify the parameters")
         
         
\ No newline at end of file
